==> 0.8.5.tar.gz: radiosonde/README.md <==
  RadioSonde Version 0.8.5
============================
<img src="http://xavier.debert.free.fr/RS/TTGO.jpg" width="50%"><img src="http://xavier.debert.free.fr/RS/TTGO2.jpg" width="50%">
<img src="http://xavier.debert.free.fr/RS/TTGO3.jpg" width="50%"><img src="http://xavier.debert.free.fr/RS/TTGO4.jpg" width="50%"><img src="http://xavier.debert.free.fr/RS/TTGO5.jpg" width="50%">
<img src="http://xavier.debert.free.fr/RS/Web4.png" width="20%"><img src="http://xavier.debert.free.fr/RS/Web.png" width="20%">
<img src="http://xavier.debert.free.fr/RS/Web3.png" width="20%"><img src="http://xavier.debert.free.fr/RS/Web2.png" width="20%">
<img src="http://xavier.debert.free.fr/RS/Web5.png" width="20%">


Projet basé sur le travail de DL9RDZ
====================================

Pour TTGO LORA 32 esp32 pico D4
Décodage de RadioSonde RS41 and DFM06/09 et M10

Attention à la version de votre TTGO!
vous devez modifier dans config.txt, le port de l'écran OLED 
-  TTGO v1:  SDA=4  SCL=15, RST=16 
-  TTGO v2:  SDA=21 SCL=22, RST=16

## Version en production 0.8.5 et devel 0.8.7

## 0.8.0 
travail de refonte et réécriture du code
## 0.8.1 
modification de la partie Web
## 0.8.5 
Evolution majeur du système 
affichage du pourcentage de la batterie en mode scanning
création d'une fenetre Batterie, Boussole
suppresion lib et code TFT
création Azimute, elevation correction de Bugs majeur , mineur
Ajout fonction Smetre, Buzzer, QTH,  Gps on off ...
mise à jour OTA
trop de modification pour toutes les expliciter!


## Les Boutons optionnel à ajouter(souder)
sur les GPIO 1002 et 1004 
attention:

+5V--[ SW ]---GPIO----[  R1  ]---/   R1=10 ou 12KOhms

- appuie court	        <1.5 seconds
- appuie double court   0.5 seconds
- appuie moyen          2-4 seconds
- appuie long           >5 seconds

## Wifi configuration

Au démarrage, si aucune connexion possible au wifi paramètré, il monte un Wifi AP
le SSID et mot de passe par défaut est: Radiosonde
en mode AP, il doit être en 192.168.4.1,
mais vous avez aussi la possibilité de mettre http://radiosonde.local dans n'importe quel Wifi 
connecté.



## Mode Scanne

Le fichier qrg.txt contient la liste par défaut des cannaux.
pour y configurer les noms, fréquences et mode [M=M10, 6=DFM06, 9=DFM09 et 4=RS41]


## Mode Réception

En réception, une seul fréquence  est décodé, les infos de la sonde (ID, GPS, RSSI, ...)
seront affichées dans plusieur fenetre à choisir ( 0 à 6) à configurer dans la page Web
rubrique config.
In receiving mode, a single frequency will be decoded, and sonde info (ID, GPS
coordinates, RSSI) will be displayed. The bar above the IP address indicates,
for the last 18 frames, if reception was successfull (|) or failed (.) 
A DOUBLE press will switch to scanning mode.
A SHORT press will switch to the next channel in channels.txt

## Mode Analyseur

Le mode analyseur de spectre (400..406 MHz) est affiché (chaque ligne == 50 kHz)
Pour les cartes TTGO sans bouton configurable, il y a un nouveau paramètre dans config.txt:
- spectrum=10       // 0=off / 1-99 nombre de seconds pour afficher l'analyseur
- timer=1           // 0=off / 1= afficher le compte à rebours du spectre dans l'affichage du spectre
- marker=1          // 0=off / 1= afficher la fréquence dans l'affichage du spectre

## Setup

voir Setup.md pour l'installation!

73
Xavier

==> 0.8.7.tar.gz: radiosonde/README.md <==
  RadioSonde Version 0.8.7
============================
<img src="http://xavier.debert.free.fr/RS/TTGO.jpg" width="50%"><img src="http://xavier.debert.free.fr/RS/TTGO2.jpg" width="50%">
<img src="http://xavier.debert.free.fr/RS/TTGO3.jpg" width="50%"><img src="http://xavier.debert.free.fr/RS/TTGO4.jpg" width="50%"><img src="http://xavier.debert.free.fr/RS/TTGO5.jpg" width="50%">
<img src="http://xavier.debert.free.fr/RS/Web4.png" width="20%"><img src="http://xavier.debert.free.fr/RS/Web.png" width="20%">
<img src="http://xavier.debert.free.fr/RS/Web3.png" width="20%"><img src="http://xavier.debert.free.fr/RS/Web2.png" width="20%">
<img src="http://xavier.debert.free.fr/RS/Web5.png" width="20%"><img src="http://xavier.debert.free.fr/RS/Web6.png" width="20%">
<img src="http://xavier.debert.free.fr/RS/Web7.png" width="20%">


Projet basé sur le travail de DL9RDZ
====================================

Pour TTGO LORA 32 esp32 pico D4
Décodage de RadioSonde RS41 and DFM06/09 et M10

Attention à la version de votre TTGO!
vous devez modifier dans config.txt, le port de l'écran OLED 
-  TTGO v1:  SDA=4  SCL=15, RST=16 
-  TTGO v2:  SDA=21 SCL=22, RST=16

## Version en production 0.8.5 devel 0.8.7

## 0.8.0 
travail de refonte et réécriture du code

## 0.8.1 

modification de la partie Web

## 0.8.5 

Evolution majeur du système 
affichage du pourcentage de la batterie en mode scanning
création d'une fenetre Batterie, Boussole
suppresion lib et code TFT
création Azimute, elevation correction de Bugs majeur , mineur
Ajout fonction Smetre, Buzzer, QTH,  Gps on off ...
mise à jour OTA
trop de modification pour toutes les expliciter!

## 0.8.7
correction bug Buzzer Off->On->Off
Add GainLNA RX SX1278FSK on Web config paramètre
Add update OTA Os + DataWeb
correction bugs sondmap.html
correction text upgrade Os et DataWeb
correction texte boussole S et N
correction bugs distance 4928Km si lat et lon =0 erroné 
correction bugs fonction Vbat
Add Telemetry width export data.csv
Suppression µSD incompatible avec pin SX1278FSK et SPI
Add transfert Telemetry To µSD on put SD automatic

## Les Boutons optionnel à ajouter(souder)
sur les GPIO 1002 et 1004 
attention:

+5V--[ SW ]---GPIO----[  R1  ]---/   R1=10 ou 12KOhms

- appuie court	        <1.5 seconds
- appuie double court   0.5 seconds
- appuie moyen          2-4 seconds
- appuie long           >5 seconds

## Wifi configuration

Au démarrage, si aucune connexion possible au wifi paramètré, il monte un Wifi AP
le SSID et mot de passe par défaut est: Radiosonde
en mode AP, il doit être en 192.168.4.1,
mais vous avez aussi la possibilité de mettre http://radiosonde.local dans n'importe quel Wifi 
connecté.



## Mode Scanne

Le fichier qrg.txt contient la liste par défaut des cannaux.
pour y configurer les noms, fréquences et mode [M=M10, 6=DFM06, 9=DFM09 et 4=RS41]


## Mode Réception

En réception, une seul fréquence  est décodé, les infos de la sonde (ID, GPS, RSSI, ...)
seront affichées dans plusieur fenetre à choisir ( 0 à 6) à configurer dans la page Web
rubrique config.
In receiving mode, a single frequency will be decoded, and sonde info (ID, GPS
coordinates, RSSI) will be displayed. The bar above the IP address indicates,
for the last 18 frames, if reception was successfull (|) or failed (.) 
A DOUBLE press will switch to scanning mode.
A SHORT press will switch to the next channel in channels.txt

## Mode Analyseur

Le mode analyseur de spectre (400..406 MHz) est affiché (chaque ligne == 50 kHz)
Pour les cartes TTGO sans bouton configurable, il y a un nouveau paramètre dans config.txt:
- spectrum=10       // 0=off / 1-99 nombre de seconds pour afficher l'analyseur
- timer=1           // 0=off / 1= afficher le compte à rebours du spectre dans l'affichage du spectre
- marker=1          // 0=off / 1= afficher la fréquence dans l'affichage du spectre

## Setup

voir Setup.md pour l'installation!

73
Xavier
